@@ -27,8 +27,8 @@ def dict2jsonFile(data={"a": 1, "b": 2, "c": 3}, fileName="data.json", RelativeP
     json_str = json.dumps(data, indent=4)
 
     with open(f"{PATH}\\{fileName}", 'w') as json_file:
-        # json_file.write(json_str)
-        json.dump(json_str, json_file)
+        json_file.write(json_str)
+        # json.dump(json_str, json_file)
 
     return True
 
@@ -58,11 +58,30 @@ def jsonFile2dict(fileName="data.json", RelativePath="\\"):
         print(f"文件不存在：{filePath}")
         return False
 
-    # 读取json文件
+    # 读取json文件，并转换为dict
     with open(filePath, 'r') as json_file:
-        json_str = json.load(json_file)
+        new_dict = json.load(json_file)
 
     # 字符串转dict
-    new_dict = json.loads(json_str)
+    # new_dict = json.loads(json_str)
 
     return new_dict
+
+
+def str2file(content="hello world!", fileName="data.txt", RelativePath="\\"):
+    # 获取项目根目录
+    ROOT_PATH = getRootPath()
+
+    if ROOT_PATH == False:
+        return False
+
+    if RelativePath != "":
+        PATH = f"{ROOT_PATH}{RelativePath}"
+    else:
+        PATH = ROOT_PATH
+    mkdir(PATH)
+
+    with open(f"{PATH}\\{fileName}", 'w') as file:
+        file.write(content)
+
+    return True
