@@ -59,8 +59,8 @@ def mkdir(path: str):
 
 def isPathExists(path: str):
     """
-        检测目录/文件是否存在
-    :param path:
+        检测 目录 或 文件 是否存在
+    :param path: 路径
     :return:
     """
     return os.path.exists(path)
